% Hill charts from non-linear turbine model without eta_i implementation - all 3 turbine types

clear all
close all
clc

de=0.025;  %for equdistant elevation curves


%--------------------------------------------------------------------------
% High head turbine
%--------------------------------------------------------------------------

% Design parameters from excel sheet - choose turbine by specifying column
 design=table2array(readtable('Hillchart_r3_medBEP.xlsx','Sheet',...
                    'Turbin_design','Range','U9:U80'));
% necessary model input:
 alfa_1R=design(49,1); sigma=design(53,1); psi=design(54,1); xi=design(56,1);

%--------------------------------------------------------------------------
y_query=linspace(0.2,1.4,13);                   %y=1.0 included
n_query=linspace(0,1.56,157);                   %n=1.0 included
q_query=linspace(0,2,201);                      %q=1.0 included
h=1;

n_query2=linspace(0.81,1.30,100);
q_query2=linspace(0.06,1.70,100);
%--------------------------------------------------------------------------

figure(1)
axis([0 1.6 0 2])
xlabel('$\tilde{\omega}$ [-]','Interpreter','latex','FontSize',16)
ylabel('$q$ [-]','Interpreter','latex','FontSize',16)
title('Model: Hill diagram at h=1','Interpreter','latex','FontSize',16)
set(legend,'Interpreter','latex','FontSize',10,'Location','west')
hold on

%torque
t=zeros(length(q_query),length(n_query));       %each row const flow, each column const speed
for j=1:length(n_query)
    qdivy=sqrt(h-sigma*(n_query(j)^2-1));
    y=q_query./qdivy;
    alfa_1=asin(y.*sin(alfa_1R*pi/180));        %radians
    m_S=xi*qdivy*(cos(alfa_1)+tan(alfa_1R*pi/180)*sin(alfa_1));
    t(:,j)=q_query.*(m_S - psi.*n_query(j));
end

%efficiency
eta=zeros(length(q_query),length(n_query));     %each row const flow, each column const speed
for i=1:length(q_query)
    eta(i,:)=(t(i,:).*n_query)./(q_query(i)*h);
end

[N,Q]=meshgrid(n_query,q_query);                %each column in N has const speed
                                                %each row in Q has const flow
ETA=real(eta);     

elev=[linspace(0,0.8,17) linspace(0.825,1.00,8)];
%elev=0:de:1;

contour(N,Q,ETA,elev,'-','LineWidth',1)
colorbar
caxis([0 1])

%flow
q=zeros(length(y_query),length(n_query));       %each row const opening, each column const speed
for i=1:length(y_query)
    q(i,:)=y_query(i)*sqrt(h-sigma*(n_query.^2-1));
    
    %plot one curve per opening degree
    plot(n_query,q(i,:),'-','LineWidth',1)
end

plot(n_query2,ones(length(n_query2))*min(q_query2),'k--',n_query2,ones(length(n_query2))*max(q_query2),'k--',...
    ones(length(q_query2))*min(n_query2),q_query2,'k--',ones(length(q_query2))*max(n_query2),q_query2,'k--',...
    'LineWidth',1)

legend('$\tilde{\eta}$','y = 0.2','y = 0.3','y = 0.4','y = 0.5','y = 0.6','y = 0.7','y = 0.8','y = 0.9',...
       'y = 1','y = 1.1','y = 1.2','y = 1.3','y = 1.4')


%--------------------------------------------------------------------------
% Medium head turbine
%--------------------------------------------------------------------------

% Design parameters from excel sheet - choose turbine by specifying column
 design=table2array(readtable('Hillchart_r3_medBEP.xlsx','Sheet',...
                    'Turbin_design','Range','T9:T80'));

% necessary model input:
 alfa_1R=design(49,1); sigma=design(53,1); psi=design(54,1); xi=design(56,1);
 
%--------------------------------------------------------------------------
y_query=linspace(0.3,1.4,12);                   %y=1.0 included
n_query=linspace(0,1.78,179);                   %n=1.0 included
q_query=linspace(0,2,201);                      %q=1.0 included
h=1;

n_query2=linspace(0.86,1.71,100);
q_query2=linspace(0.08,1.48,100);
%--------------------------------------------------------------------------

figure(2)
axis([0 1.8 0 1.8])
xlabel('$\tilde{\omega}$ [-]','Interpreter','latex','FontSize',16)
ylabel('$q$ [-]','Interpreter','latex','FontSize',16)
title('Model: Hill diagram at h=1','Interpreter','latex','FontSize',16)
set(legend,'Interpreter','latex','FontSize',10,'Location','west')
hold on

%torque
t=zeros(length(q_query),length(n_query));       %each row const flow, each column const speed
for j=1:length(n_query)
    qdivy=sqrt(h-sigma*(n_query(j)^2-1));
    y=q_query./qdivy;
    alfa_1=asin(y.*sin(alfa_1R*pi/180));        %radians
    m_S=xi*qdivy*(cos(alfa_1)+tan(alfa_1R*pi/180)*sin(alfa_1));
    t(:,j)=q_query.*(m_S - psi.*n_query(j));
end

%efficiency
eta=zeros(length(q_query),length(n_query));     %each row const flow, each column const speed
for i=1:length(q_query)
    eta(i,:)=(t(i,:).*n_query)./(q_query(i)*h);
end

[N,Q]=meshgrid(n_query,q_query);                %each column in N has const speed
                                                %each row in Q has const flow
ETA=real(eta);     

elev=[linspace(0,0.8,17) linspace(0.825,1.00,8)];
%elev=0:de:1;

contour(N,Q,ETA,elev,'-','LineWidth',1)
colorbar
caxis([0 1])

%flow
q=zeros(length(y_query),length(n_query));       %each row const opening, each column const speed
for i=1:length(y_query)
    q(i,:)=y_query(i)*sqrt(h-sigma*(n_query.^2-1));
    
    %plot one curve per opening degree
    plot(n_query,q(i,:),'-','LineWidth',1)
end

plot(n_query2,ones(length(n_query2))*min(q_query2),'k--',n_query2,ones(length(n_query2))*max(q_query2),'k--',...
    ones(length(q_query2))*min(n_query2),q_query2,'k--',ones(length(q_query2))*max(n_query2),q_query2,'k--',...
    'LineWidth',1)

legend('$\tilde{\eta}$','y = 0.3','y = 0.4','y = 0.5','y = 0.6','y = 0.7','y = 0.8','y = 0.9',...
       'y = 1','y = 1.1','y = 1.2','y = 1.3','y = 1.4')


%--------------------------------------------------------------------------
% Low head turbine
%--------------------------------------------------------------------------

% Design parameters from excel sheet - choose turbine by specifying column
 design=table2array(readtable('Hillchart_r3_medBEP.xlsx','Sheet','Turbin_design','Range','R9:R80'));

% necessary model input:
 alfa_1R=design(49,1); sigma=design(53,1); psi=design(54,1); xi=design(56,1);

%--------------------------------------------------------------------------
y_query=linspace(0.3,1.3,11);                   %y=1.0 included
n_query=linspace(0,1.9,191);                    %n=1.0 included
q_query=linspace(0,2,201);                      %q=1.0 included
h=1;

n_query2=linspace(0.94,1.47,100);
q_query2=linspace(0.32,1.34,100);
%--------------------------------------------------------------------------

figure(3)
axis([0 1.9 0 1.8])
xlabel('$\tilde{\omega}$ [-]','Interpreter','latex','FontSize',16)
ylabel('$q$ [-]','Interpreter','latex','FontSize',16)
title('Model: Hill diagram at h=1','Interpreter','latex','FontSize',16)
set(legend,'Interpreter','latex','FontSize',10,'Location','west')
hold on

%torque
t=zeros(length(q_query),length(n_query));       %each row const flow, each column const speed
for j=1:length(n_query)
    qdivy=sqrt(h-sigma*(n_query(j)^2-1));
    y=q_query./qdivy;
    alfa_1=asin(y.*sin(alfa_1R*pi/180));        %radians
    m_S=xi*qdivy*(cos(alfa_1)+tan(alfa_1R*pi/180)*sin(alfa_1));
    t(:,j)=q_query.*(m_S - psi.*n_query(j));
end

%efficiency
eta=zeros(length(q_query),length(n_query));     %each row const flow, each column const speed
for i=1:length(q_query)
    eta(i,:)=(t(i,:).*n_query)./(q_query(i)*h);
end

[N,Q]=meshgrid(n_query,q_query);                %each column in N has const speed
                                                %each row in Q has const flow
ETA=real(eta);     

elev=[linspace(0,0.8,17) linspace(0.825,1.00,8)];
%elev=0:de:1;

contour(N,Q,ETA,elev,'-','LineWidth',1)
colorbar
caxis([0 1])

%flow
q=zeros(length(y_query),length(n_query));       %each row const opening, each column const speed
for i=1:length(y_query)
    q(i,:)=y_query(i)*sqrt(h-sigma*(n_query.^2-1));
    
    %plot one curve per opening degree
    plot(n_query,q(i,:),'-','LineWidth',1)
end

plot(n_query2,ones(length(n_query2))*min(q_query2),'k--',n_query2,ones(length(n_query2))*max(q_query2),'k--',...
    ones(length(q_query2))*min(n_query2),q_query2,'k--',ones(length(q_query2))*max(n_query2),q_query2,'k--',...
    'LineWidth',1)

legend('$\tilde{\eta}$','y = 0.3','y = 0.4','y = 0.5','y = 0.6','y = 0.7','y = 0.8','y = 0.9',...
       'y = 1','y = 1.1','y = 1.2','y = 1.3')
